==> haskell-hslua-module-version-1.1.0-48-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-version.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-module-version
version:              1.1.0
visibility:           public
id:                   hslua-module-version-1.1.0-Jh6Jr1e8pKK5QucQFT7jJq
key:                  hslua-module-version-1.1.0-Jh6Jr1e8pKK5QucQFT7jJq
license:              MIT
copyright:            © 2019-2023 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Lua module to work with version specifiers.
description:          Wrapper for the Data.Version.Version Haskell type.
category:             Foreign
abi:                  613da41d1c39b4d69b60c488bd751a59
exposed:              True
exposed-modules:      HsLua.Module.Version
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-module-version-1.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-module-version-1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-version
hs-libraries:         HShslua-module-version-1.1.0-Jh6Jr1e8pKK5QucQFT7jJq
depends:
    base-4.16.4.0 filepath-1.4.2.2
    hslua-core-2.3.1-IyI9OufFuBtHH3ZMlxCaYs
    hslua-marshalling-2.3.0-Ig2P4Cxc1BcAg3kht9VCbg
    hslua-packaging-2.3.1-IUoPNcKfN1bCEmWPniFc9y text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-version/html/hslua-module-version.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-version/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-version-1.1.0-53-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-version.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-module-version
version:              1.1.0
visibility:           public
id:                   hslua-module-version-1.1.0-CHEx8HGhHiu2uf8mY5gsSt
key:                  hslua-module-version-1.1.0-CHEx8HGhHiu2uf8mY5gsSt
license:              MIT
copyright:            © 2019-2023 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Lua module to work with version specifiers.
description:          Wrapper for the Data.Version.Version Haskell type.
category:             Foreign
abi:                  6c91e390b7abbf59a17cc1caaafa8f3f
exposed:              True
exposed-modules:      HsLua.Module.Version
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-module-version-1.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-module-version-1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-version
hs-libraries:         HShslua-module-version-1.1.0-CHEx8HGhHiu2uf8mY5gsSt
depends:
    base-4.16.4.0 filepath-1.4.2.2
    hslua-core-2.3.1-JQGJo3eBQf079Ax0WDYvHs
    hslua-marshalling-2.3.1-LfjRsOKxODRHmzulq0UW2i
    hslua-packaging-2.3.1-75crFeaKnIA3BOg7rdX9ZZ text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-version/html/hslua-module-version.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-version/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
